# Generated by Django 2.2.3 on 2019-08-13 05:07

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='PaymentTypeModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=50, unique=True)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=9)),
                ('payment_plan', models.PositiveIntegerField(blank=True, null=True, unique=True)),
                ('currency', models.CharField(default='USD', max_length=3)),
                ('custom_logo', models.URLField(blank=True, max_length=500, null=True)),
                ('custom_title', models.CharField(blank=True, max_length=200, null=True)),
                ('pay_button_text', models.CharField(default='Sign Up', max_length=100)),
                ('payment_options', models.CharField(default='card', max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name='TransactionModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_datetime', models.DateTimeField(auto_now_add=True)),
                ('reference', models.CharField(max_length=200, unique=True)),
                ('flutterwave_reference', models.CharField(max_length=200, unique=True)),
                ('order_reference', models.CharField(max_length=200, unique=True)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=9)),
                ('charged_amount', models.DecimalField(decimal_places=2, max_digits=9)),
                ('status', models.CharField(max_length=50)),
                ('payment_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transactions', to='djangorave.PaymentTypeModel')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transactions', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
