# Generated by Django 2.2.3 on 2019-08-15 05:24

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('djangorave', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymenttypemodel',
            name='created_datetime',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='transactionmodel',
            name='flutterwave_reference',
            field=models.CharField(max_length=200),
        ),
        migrations.AlterField(
            model_name='transactionmodel',
            name='order_reference',
            field=models.CharField(max_length=200),
        ),
        migrations.AlterField(
            model_name='transactionmodel',
            name='reference',
            field=models.CharField(max_length=200),
        ),
    ]
